summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Python/ceval.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/Python/ceval.c b/Python/ceval.c
index abb934d..d34d6bf 100644
--- a/Python/ceval.c
+++ b/Python/ceval.c
@@ -630,8 +630,8 @@ _PyEval_AddPendingCall(PyInterpreterState *interp,
{
struct _pending_calls *pending = &interp->ceval.pending;
- /* Ensure that _PyEval_InitPendingCalls() was called
- and that _PyEval_FiniPendingCalls() is not called yet. */
+ /* Ensure that _PyEval_InitState() was called
+ and that _PyEval_FiniState() is not called yet. */
assert(pending->lock != NULL);
PyThread_acquire_lock(pending->lock, WAIT_LOCK);